===========================
Specifications are Advisory
===========================

This project is under heavy active development.  Specifications in this repository
reflects general consensus of ideas at the time the specification was conceived rather
then set of actions to take or a commitment to precisely implement the specification.
As an example, kolla-ansible looks much different today than then ansible-multi spec.
For Kolla old-timers, many know that Kolla in its present form may not have existed
without this general consensus of ideas set by ansible-multi.

All specifications in this repository are subject to abandonment in the future if
the development team finds it necessary to change course.

The single source of truth for development work is recorded in blueprints as specifications
are immutable once committed to the repository.  Blueprints on the other hand are dynamic
and may be changed at any time along with the codebase.
